#header-navigation > div:first-child {
    position: relative;
}

@media (max-width: 991px) {
    .fr-nav__btn[aria-current]:not([aria-current="false"]),
    .fr-nav__link[aria-current]:not([aria-current="false"]) {
        text-decoration: underline;
    }
}

.fr-notice[data-show="false"] {
    display: none;
}

.fr-notice[data-show="true"] {
    display: block;
}

.fr-notice__link {
    text-decoration: underline;
}

.internal-outline:focus {
    outline-offset: -2px;
}
