<aside id="slide-panel-{% block "type" %}{% endblock %}" role="dialog" aria-modal="true" aria-label="{% block "aria-label" %}{% endblock %}" class="tdbmd-slide-panel">
    <button
        class="tdbmd-slide-panel__btn fr-btn fr-btn--tertiary"
        data-side-panel-close="true"
    >
        <span
        className="tdbmd-slide-panel__icon"
            aria-hidden="true"
        >
            <div style="width: 24px; transform: rotate(180deg);">
                {% include "territories_dashboard_lib/website/svg/delete-back.svg" %}
            </div>
        </span>
        <span class="fr-sr-only">Fermer</span>
    </button>
    <div class="tdbmd-slide-panel__content">
        <button
            class="fr-btn fr-btn--tertiary tdbmd-slide-panel__btn--mobile fr-mb-2w fr-mt-3w fr-ml-4w"
            data-side-panel-close="true"
        >
            Fermer
        </button>
        <div id="slide-panel-content">
            {% block "content" %}{% endblock %}
        </div>
    </div>
</aside>
