<div class="chart-buttons" {% if no_pb %}style="padding-bottom: 0px;"{% endif %}>
    <button
        aria-label="Exporter le graphique {{ name }} en png{% if not one_indicator %} - {{ indicator.title }}{% endif %}"
        data-title="{{ name }}"
        data-trackingobjet="{{ tracking_objet }}"
        data-type="export-png"
        class="fr-btn fr-btn--secondary fr-btn--sm fr-icon-image-line fr-btn--icon-right btn-download">
        Exporter le graphique en png
    </button>
    <button
        aria-label="Exporter le graphique {{ name }} en csv{% if not one_indicator %} - {{ indicator.title }}{% endif %}"
        id="{{indicator.id}}{{ route }}-export-csv"
        data-title="{{ name }}"
        data-route="{{ route }}"
        data-type="export-csv"
        class="fr-btn fr-btn--secondary fr-btn--sm fr-icon-line-chart-line fr-btn--icon-right btn-download">
        Exporter le graphique en csv
    </button>
    {% if pattern %}
        <div class="fr-toggle">
            <input
                type="checkbox"
                class="fr-toggle__input pattern-toggle"
                id="{{ route }}-pattern-toggle"
                aria-label="Ajouter des motifs au graphique {{ name }}{% if not one_indicator %} - {{ indicator.title }}{% endif %}"
            >
            <label class="checkbox-label fr-toggle__label fr-text--sm" for="{{ route }}-pattern-toggle">Ajouter des motifs</label>
        </div>
    {% endif %}
</div>
