{% load other_filters %}

{% if indicator.flows_db_table_prefix %}
    <div class="subtheme">
        <div class="fr-px-md-4w fr-px-2w fr-py-2w">
            {% include "territories_dashboard_lib/website/pages/indicators/components/title.html" with title="Top 10 des flux par origine-destination (diagramme de Sankey)" key="sankey" text="Survolez les flux sur le graphique pour afficher les valeurs. Vous pouvez filtrer selon le mode de déplacement en sélectionnant les filtres disponibles sous le titre du graphique. Précisions : Seuls les flux entre les 10 territoires qui génèrent le plus de flux depuis/vers le territoire sélectionné sont affichés." %}
            <div style="width:100%; height: auto;">
            <div id="sankey-graph"></div>
            </div>
        </div>
        <button
            data-title="Sankey"
            class="fr-btn fr-btn--secondary fr-btn--sm fr-icon-line-chart-line fr-btn--icon-right fr-mx-4w fr-mt-4w fr-mb-4w btn-download">
            <span>Exporter le graphique</span>
        </button>
    </div>
{% endif %}