# Generated by Django 5.1.6 on 2025-06-23 12:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('website_lib', '0002_mainconf_contact_email_mainconf_newsletter_link_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='mainconf',
            name='footer_navigation',
            field=models.TextField(default='', help_text='Navigation du footer, mettre les liens au format markdown, un par ligne. <br/><br/>\n    Si le lien est interne, commencer et terminer le lien par un slash comme "/accueil/"<br/><br/>\n    Par exemple : <br/><br/>\n    [Plan du site](/plan-site/)<br/>\n    [Accessibilité](/accessibilite/)<br/>\n    [Mentions légales](/mentions-legales/) <br/>\n    ', verbose_name='Navigation du footer'),
        ),
        migrations.AlterField(
            model_name='mainconf',
            name='header_navigation',
            field=models.TextField(default='', help_text='Navigation du header, mettre les liens au format markdown avec un slash à la fin du lien, mettre une ligne vide entre chaque rubrique. <br/><br/>\n        \n        Une rubrique peut contenir un seul lien, ou bien plusiers, dans ce cas la rubrique sera sous forme de dropdown et il faut mettre un titre en premier. <br/><br/>Par exemple : <br/>\n        <br/><br/>\n        [Accueil](/accueil/)\n        <br/><br/>\n        [Indicateurs territoriaux](/indicateurs/)\n        <br/><br/>\n        À propos\n        [Présentation](/presentation/)\n        [Journal des versions](/journal/)\n        ', verbose_name='Navigation du header'),
        ),
    ]
