{% extends "territories_dashboard_lib/website/layout/base.html" %}

{% load static %}

{% block page_title %}{{ static_page.name }}{% endblock %}

{% block extra_head%}
    <script defer type="module" src="{% static 'territories_dashboard_lib/website/js/pages/static/page.mjs' %}"></script>
{% endblock %}

{% block css %}
    {% include "territories_dashboard_lib/website/pages/static/page.css" %}
{% endblock %}

{% block main %}

<main role="main" id="contenu" tabindex="-1" class="staticPage fr-container fr-pt-10w fr-pb-10w">
    {{ static_page.body_html|safe }}
</main>
{% endblock %}
