{% load other_filters %}

<div class="subtheme fr-px-md-4w fr-p-2w">
    {% if params|should_mesh_analysis:indicator %}
        <div id="indicator-map"></div>
    {% else %}
        <h3 class="fr-mt-4w">Carte</h3>
        <div>La carte n'est pas disponible pour la maille sélectionnée.</div>
    {% endif %}
</div>