.data-table {
    overflow-x: auto;
}

.data-table-export-buttons {
    margin-bottom: 16px;
    margin-top: 16px;
    display: flex;
    gap: 16px;
    flex-wrap: wrap;
}

.fr-pagination__link.fr-pagination__link-override {
    margin-left: 0.2rem;
    margin-right: 0.2rem;
}

.fr-pagination__link.fr-pagination__link-override:hover {
    margin-left: 0.2rem;
    margin-right: 0.2rem;
    background-color: #f6f6f6;
}

.orderableTh > div:first-child {
    display: flex;
    justify-content: center;
    align-items: center;
    gap: 4px;
}

.tdbmd-table {
    width: 100%;
    border-collapse: collapse;
    border: 1px solid #929292;
    text-align: left;
}

.tdbmd-table tbody > tr:focus > td {
    background-color: #ececfe;
}

.tdbmd-table td {
    background-color: white;
    font-size: smaller;
}

.tdbmd-table th {
    background-color: #f6f6f6;
    cursor: pointer;
    justify-content: center;
}

.tdbmd-table th .orderArrow {
    font-size: 14px;
}
.tdbmd-table th,
.tdbmd-table td {
    padding: 8px 16px;
    border: 1px solid #929292;
}
.tdbmd-table th .orderArrow.orderArrowBoth {
    font-size: 20px;
    padding-bottom: 4px;
}

.tdbmd-table th[data-name="annee"] {
    width: 64px;
}

.tdbmd-table th[data-name="lieu"] {
    width: 35%;
}

.tdbmd-table-container {
    max-width: 900px;
}

.tdbmd-table-header {
    width: 100%;
    display: flex;
    justify-content: end;
    margin-bottom: 1rem;
}
