{% extends "territories_dashboard_lib/website/layout/base.html" %}

{% load static %}

{% block page_title %}Plan du site{% endblock %}

{% block main %}
<main role="main" class="fr-container fr-pt-md-8w fr-pb-md-10w fr-pt-4w fr-pb-6w" id="contenu" tabindex="-1">
  <h2>Plan du site</h2>
  <ul>
    <li>
        <a href="{% url 'website:landing-page' %}">Accueil</a>
    </li>
  </ul>
  <br/>
  <h3>Thématiques</h3>
  <ul>
    {% for theme in themes %}
      <li>
        <a href="{% url 'website:theme' theme_name=theme.name %}">{{theme.title}}</a>
      </li>
    {% endfor %}
  </ul>
  <br/>
  <h3>Comparaison par thématiques</h3>
  <ul>
    {% for theme in themes %}
      <li>
        <a href="{% url 'website:comparison' theme_name=theme.name %}">{{theme.title}}</a>
      </li>
    {% endfor %}
  </ul>
  <br/>
  <h3>Détails des indicateurs</h3>
  <ul>
    {% for indicator in indicators %}
      <li>
        <a href="{% url 'website:indicator-details' indicator_name=indicator.name %}">{{indicator.title}}</a>
      </li>
    {% endfor %}
  </ul>
  <br/>
  {% if ENABLE_SUPERSET and dashboards %}
    <h3>Portraits de territoires</h3>
    <ul>
      {% for dashboard in dashboards %}
        <li>
          <a href="{% url 'website:superset' dashboard_name=dashboard.short_name %}">{{dashboard.label}}</a>
        </li>
      {% endfor %}
    </ul>
    <br/>
  {% endif %}
  <h3>Autres pages</h3>
  <ul>
    {% for static_page in static_pages %}
    <li>
      <a href="{{ static_page.url }}">{{ static_page.title }}</a>
    </li>
    {% endfor %}
    {% if lexique %}
        <li>
            <a href="{% url 'website:lexique' %}">Lexique</a>
        </li>
    {% endif %}
    <li>
      <a href="{% url 'website:sitemap' %}">Plan du site</a>
    </li>
  </ul>
</main>
{% endblock %}
