# Generated by Django 5.2.6 on 2025-09-23 12:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('website_lib', '0003_alter_mainconf_footer_navigation_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='mainconf',
            name='description',
            field=models.TextField(blank=True, help_text='Utilisé pour la balise meta description du site et pour le relais sur les réseaux sociaux.', null=True, verbose_name='Description du site'),
        ),
        migrations.AddField(
            model_name='mainconf',
            name='social_image_url',
            field=models.TextField(blank=True, help_text="Lien d'une image (idéalement 1200x630px). Elle sera utilisée lors du partage sur les réseaux sociaux.", null=True, verbose_name='Image de description'),
        ),
    ]
