.fr-header__logo:hover {
    background-color: var(--grey-1000-50-hover);
}

.delay-spinner {
    opacity: 0%;
}

.filters-dimension {
    display: flex;
    flex-direction: column;
}

.filters-dimension > label {
    margin-bottom: 4px;
    font-style: italic;
    font-size: smaller;
}

.filters-dimension:not(:last-child) {
    margin-bottom: 16px;
}

.fr-tag-list .fr-tag {
    margin: 0 0.25rem 0.5rem;
    vertical-align: top;
}

.tdbmd-content {
    position: relative;
}

.tdbmd-indicator-source {
    font-style: italic;
}

.tdbmd-indicator-source__title {
    text-decoration: underline;
}

.tdbmd-thematics {
    box-sizing: border-box;
}

.tdbmd-thematics .fr-sidemenu {
    padding-right: 0;
    margin: 0;
}

.tdbmd-thematics .fr-sidemenu__inner {
    box-shadow: none;
}

.tdbmd-thematics .subtheme h2 {
    padding: 1rem 0;
    margin-bottom: 0;
}

.tdbmd-thematics .subtheme:nth-child(even) {
    background: var(--background-alt-blue-france);
}

.tdbmd-thematics .subtheme:nth-child(odd) {
    background: white;
}

.tdbmd-thematics__content {
    box-sizing: border-box;
    border-left: 1px solid var(--border-default-grey);
}
.tdbmd-thematics__btns {
    display: flex;
    flex-direction: column;
    gap: 1rem;
    margin: 0 1rem;
}
@media (min-width: 575px) {
    .tdbmd-thematics__btns {
        flex-direction: row;
        justify-content: flex-end;
    }
}
