<span style="display: inline-block; width: {{width}}px;">
    <svg
        xmlns="http://www.w3.org/2000/svg"
        xmlnsXlink="http://www.w3.org/1999/xlink"
        viewBox="0 0 100 100"
        preserveAspectRatio="xMidYMid"
    >
        <circle
            cx="50"
            cy="50"
            r="35"
            stroke-width="10"
            stroke="#6a6af4"
            stroke-dasharray="180"
            fill="none"
            stroke-linecap="round"
        >
            <animateTransform
                attributeName="transform"
                type="rotate"
                repeatCount="indefinite"
                dur="1.1764705882352942s"
                keyTimes="0;1"
                values="0 50 50;360 50 50"
            ></animateTransform>
        </circle>
    </svg>
</span>
